### Python version >= 3.6

## Common code for myself.

## Features:

1. Combine config & config_local.
1. @log annotation.
1. logger helper.
1. email helper.
1. load & dump json.
1. @benchmark annotation.
1. GetCh for multiple platforms.
1. Get windows folders.
1. @deprecated annotation.
1. deep merge.